pub struct BareCommand {Show 14 fields
config: SqlnessConfig,
server_addr: ServerAddr,
wal: Wal,
kafka_wal_broker_endpoints: Option<String>,
bins_dir: Option<PathBuf>,
preserve_state: bool,
pull_version_on_need: bool,
store_addrs: Vec<String>,
setup_etcd: bool,
setup_pg: Option<ServiceProvider>,
setup_mysql: Option<ServiceProvider>,
jobs: usize,
extra_args: Vec<String>,
enable_flat_format: bool,
}Expand description
Run sqlness tests in bare mode.
Fields
config: SqlnessConfigserver_addr: ServerAddrAddresses of the server.
wal: WalThe type of Wal.
kafka_wal_broker_endpoints: Option<String>The kafka wal broker endpoints. This config will suppress sqlness runner from starting a kafka cluster, and use the given endpoint as kafka backend.
bins_dir: Option<PathBuf>The path to the directory where GreptimeDB’s binaries resides. If not set, sqlness will build GreptimeDB on the fly.
preserve_state: boolPreserve persistent state in the temporary directory. This may affect future test runs.
pull_version_on_need: boolPull Different versions of GreptimeDB on need.
store_addrs: Vec<String>The store addresses for metadata, if empty, will use memory store.
setup_etcd: boolWhether to setup etcd, by default it is false.
setup_pg: Option<ServiceProvider>Whether to setup pg, by default it is false.
setup_mysql: Option<ServiceProvider>Whether to setup mysql, by default it is false.
jobs: usizeThe number of jobs to run in parallel. Default to half of the cores.
extra_args: Vec<String>Extra command line arguments when starting GreptimeDB binaries.
enable_flat_format: boolEnable flat format for storage engine (sets default_flat_format = true).
Implementations
Sourceimpl BareCommand
impl BareCommand